@@ -3,20 +3,19 @@ from __future__ import absolute_import
 import json
 import os
 import yaml
-import six
 
-from ansible import __version__ as ANSIBLE_VERSION
+import pytest
 
 from ansible_runner.interface import init_runner
 
-import pytest
 
 HERE = os.path.abspath(os.path.dirname(__file__))
 
 
 @pytest.fixture()
-def executor(tmpdir, request, is_pre_ansible28):
-    private_data_dir = six.text_type(tmpdir.mkdir('foo'))
+def executor(tmp_path, request):
+    private_data_dir = tmp_path / 'foo'
+    private_data_dir.mkdir()
 
     playbooks = request.node.callspec.params.get('playbook')
     playbook = list(playbooks.values())[0]
@@ -28,10 +27,7 @@ def executor(tmpdir, request, is_pre_ansible28):
     # python interpreter used is not of much interest, we really want to silence warnings
     envvars['ANSIBLE_PYTHON_INTERPRETER'] = 'auto_silent'
 
-    if is_pre_ansible28:
-        inventory = 'localhost ansible_connection=local ansible_python_interpreter="/usr/bin/env python"'
-    else:
-        inventory = 'localhost ansible_connection=local'
+    inventory = 'localhost ansible_connection=local ansible_python_interpreter="{{ ansible_playbook_python }}"'
 
     r = init_runner(
         private_data_dir=private_data_dir,
@@ -76,9 +72,9 @@ def executor(tmpdir, request, is_pre_ansible28):
     {'ANSIBLE_CALLBACK_PLUGINS': ''}],
     ids=['local-callback-plugin', 'no-callback-plugin']
 )
-def test_callback_plugin_receives_events(executor, event, playbook, envvars):
+def test_callback_plugin_receives_events(executor, event, playbook, envvars):  # pylint: disable=W0613,W0621
     executor.run()
-    assert len(list(executor.events))
+    assert list(executor.events)
     assert event in [task['event'] for task in executor.events]
 
 
@@ -161,9 +157,9 @@ def test_callback_plugin_receives_events(executor, event, playbook, envvars):
         ignore_errors: yes
 '''},  # noqa
 ])
-def test_callback_plugin_no_log_filters(executor, playbook):
+def test_callback_plugin_no_log_filters(executor, playbook):  # pylint: disable=W0613,W0621
     executor.run()
-    assert len(list(executor.events))
+    assert list(executor.events)
     assert 'SENSITIVE' not in json.dumps(list(executor.events))
 
 
@@ -180,7 +176,7 @@ def test_callback_plugin_no_log_filters(executor, playbook):
     - uri: url=https://example.org url_username="PUBLIC" url_password="PRIVATE"
 '''},  # noqa
 ])
-def test_callback_plugin_task_args_leak(executor, playbook, skipif_pre_ansible28):
+def test_callback_plugin_task_args_leak(executor, playbook):  # pylint: disable=W0613,W0621
     executor.run()
     events = list(executor.events)
     assert events[0]['event'] == 'playbook_on_start'
@@ -202,7 +198,32 @@ def test_callback_plugin_task_args_leak(executor, playbook, skipif_pre_ansible28
     assert not events[-1]['event_data']['failures'], 'Unexpected playbook execution failure'
 
 
-@pytest.mark.parametrize('playbook', [
+@pytest.mark.parametrize(
+    "playbook",
+    [
+        {
+            "simple.yml": """
+- name: simpletask
+  connection: local
+  hosts: all
+  gather_facts: no
+  tasks:
+    - shell: echo "resolved actions test!"
+"""
+        },  # noqa
+    ],
+)
+def test_resolved_actions(executor, playbook, skipif_pre_ansible212):  # pylint: disable=W0613,W0621
+    executor.run()
+    events = list(executor.events)
+
+    # task 1
+    assert events[2]["event"] == "playbook_on_task_start"
+    assert "resolved_action" in events[2]["event_data"]
+    assert events[2]["event_data"]["resolved_action"] == "ansible.builtin.shell"
+
+
+@pytest.mark.parametrize("playbook", [
 {'loop_with_no_log.yml': '''
 - name: playbook variable should not be overwritten when using no log
   connection: local
@@ -217,7 +238,7 @@ def test_callback_plugin_task_args_leak(executor, playbook, skipif_pre_ansible28
     - debug: msg="{{ command_register.results|map(attribute='stdout')|list }}"
 '''},  # noqa
 ])
-def test_callback_plugin_censoring_does_not_overwrite(executor, playbook, skipif_pre_ansible28):
+def test_callback_plugin_censoring_does_not_overwrite(executor, playbook):  # pylint: disable=W0613,W0621
     executor.run()
     events = list(executor.events)
     assert events[0]['event'] == 'playbook_on_start'
@@ -226,7 +247,7 @@ def test_callback_plugin_censoring_does_not_overwrite(executor, playbook, skipif
     # task 1
     assert events[2]['event'] == 'playbook_on_task_start'
     # Ordering of task and item events may differ randomly
-    assert set(['runner_on_start', 'runner_item_on_ok', 'runner_on_ok']) == set([data['event'] for data in events[3:6]])
+    assert set(['runner_on_start', 'runner_item_on_ok', 'runner_on_ok']) == {data['event'] for data in events[3:6]}
 
     # task 2 no_log=True
     assert events[6]['event'] == 'playbook_on_task_start'
@@ -244,9 +265,9 @@ def test_callback_plugin_censoring_does_not_overwrite(executor, playbook, skipif
     - shell: echo "Hello, World!"
 '''},  # noqa
 ])
-def test_callback_plugin_strips_task_environ_variables(executor, playbook):
+def test_callback_plugin_strips_task_environ_variables(executor, playbook):  # pylint: disable=W0613,W0621
     executor.run()
-    assert len(list(executor.events))
+    assert list(executor.events)
     for event in list(executor.events):
         assert os.environ['PATH'] not in json.dumps(event)
 
@@ -262,7 +283,7 @@ def test_callback_plugin_strips_task_environ_variables(executor, playbook):
           foo: "bar"
 '''},  # noqa
 ])
-def test_callback_plugin_saves_custom_stats(executor, playbook, skipif_pre_ansible28):
+def test_callback_plugin_saves_custom_stats(executor, playbook):  # pylint: disable=W0613,W0621
     executor.run()
     for event in executor.events:
         event_data = event.get('event_data', {})
@@ -288,10 +309,9 @@ def test_callback_plugin_saves_custom_stats(executor, playbook, skipif_pre_ansib
         - my_handler
 '''},  # noqa
 ])
-@pytest.mark.skipif(ANSIBLE_VERSION < '2.5', reason="v2_playbook_on_notify doesn't work before ansible 2.5")
-def test_callback_plugin_records_notify_events(executor, playbook, skipif_pre_ansible28):
+def test_callback_plugin_records_notify_events(executor, playbook):  # pylint: disable=W0613,W0621
     executor.run()
-    assert len(list(executor.events))
+    assert list(executor.events)
     notify_events = [x for x in executor.events if x['event'] == 'playbook_on_notify']
     assert len(notify_events) == 1
     assert notify_events[0]['event_data']['handler'] == 'my_handler'
@@ -313,17 +333,17 @@ def test_callback_plugin_records_notify_events(executor, playbook, skipif_pre_an
         url_password: "{{ pw }}"
 '''},  # noqa
 ])
-def test_module_level_no_log(executor, playbook, skipif_pre_ansible28):
+def test_module_level_no_log(executor, playbook):  # pylint: disable=W0613,W0621
     # It's possible for `no_log=True` to be defined at the _module_ level,
     # e.g., for the URI module password parameter
     # This test ensures that we properly redact those
     executor.run()
-    assert len(list(executor.events))
+    assert list(executor.events)
     assert 'john-jacob-jingleheimer-schmidt' in json.dumps(list(executor.events))
     assert 'SENSITIVE' not in json.dumps(list(executor.events))
 
 
-def test_output_when_given_invalid_playbook(tmpdir):
+def test_output_when_given_invalid_playbook(tmp_path):
     # As shown in the following issue:
     #
     #   https://github.com/ansible/ansible-runner/issues/29
@@ -334,21 +354,22 @@ def test_output_when_given_invalid_playbook(tmpdir):
     #   https://github.com/ansible/ansible-runner/pull/34
     #
     # But no test validated it.  This does that.
-    private_data_dir = str(tmpdir)
-    executor = init_runner(
+    private_data_dir = str(tmp_path)
+    ex = init_runner(
         private_data_dir=private_data_dir,
-        inventory="localhost ansible_connection=local",
+        inventory='localhost ansible_connection=local ansible_python_interpreter="{{ ansible_playbook_python }}"',
         envvars={"ANSIBLE_DEPRECATION_WARNINGS": "False"},
         playbook=os.path.join(private_data_dir, 'fake_playbook.yml')
     )
 
-    executor.run()
-    stdout = executor.stdout.read()
+    ex.run()
+    with ex.stdout as f:
+        stdout = f.read()
     assert "ERROR! the playbook:" in stdout
     assert "could not be found" in stdout
 
 
-def test_output_when_given_non_playbook_script(tmpdir):
+def test_output_when_given_non_playbook_script(tmp_path):
     # As shown in the following pull request:
     #
     #   https://github.com/ansible/ansible-runner/pull/256
@@ -360,7 +381,7 @@ def test_output_when_given_non_playbook_script(tmpdir):
     # this is a retro-active test based on the sample repo provided in the PR:
     #
     #   https://github.com/AlanCoding/ansible-runner-examples/tree/master/non_playbook/sleep_with_writes
-    private_data_dir = str(tmpdir)
+    private_data_dir = str(tmp_path)
     with open(os.path.join(private_data_dir, "args"), 'w') as args_file:
         args_file.write("bash sleep_and_write.sh\n")
     with open(os.path.join(private_data_dir, "sleep_and_write.sh"), 'w') as script_file:
@@ -371,18 +392,20 @@ def test_output_when_given_non_playbook_script(tmpdir):
     with open(os.path.join(private_data_dir, "env", "settings"), 'w') as settings_file:
         settings_file.write("pexpect_timeout: 0.2")
 
-    executor = init_runner(
+    ex = init_runner(
         private_data_dir=private_data_dir,
-        inventory="localhost ansible_connection=local",
+        inventory='localhost ansible_connection=local ansible_python_interpreter="{{ ansible_playbook_python }}"',
         envvars={"ANSIBLE_DEPRECATION_WARNINGS": "False"}
     )
 
-    executor.run()
-    stdout = executor.stdout.readlines()
+    ex.run()
+
+    with ex.stdout as f:
+        stdout = f.readlines()
     assert stdout[0].strip() == "hi world"
     assert stdout[1].strip() == "goodbye world"
 
-    events = list(executor.events)
+    events = list(ex.events)
 
     assert len(events) == 2
     assert events[0]['event'] == 'verbose'
@@ -403,18 +426,17 @@ def test_output_when_given_non_playbook_script(tmpdir):
         msg: "{{ ('F' * 150) | list }}"
 '''},  # noqa
 ])
-def test_large_stdout_parsing_when_using_json_output(executor, playbook, skipif_pre_ansible28):
+def test_large_stdout_parsing_when_using_json_output(executor, playbook):  # pylint: disable=W0613,W0621
     # When the json flag is used, it is possible to output more data than
     # pexpect's maxread default of 2000 characters.  As a result, if not
     # handled properly, the stdout can end up being corrupted with partial
     # non-event matches with raw "non-json" lines being intermixed with json
     # ones.
     #
-    # This tests to confirm we don't polute the stdout output with non-json
+    # This tests to confirm we don't pollute the stdout output with non-json
     # lines when a single event has a lot of output.
-    if six.PY2:
-        pytest.skip('Ansible in python2 uses different syntax.')
     executor.config.env['ANSIBLE_NOCOLOR'] = str(True)
     executor.run()
-    text = executor.stdout.read()
+    with executor.stdout as f:
+        text = f.read()
     assert text.count('"F"') == 150
